@@ -336,7 +336,7 @@ class DateMatcher(object):
                     {
                         "start": entities[i]["start"],
                         "end": entities[i]["end"],
-                        "entity": "date_time",
+                        "entity": "date",
                         "value": value[i],
                         "confidence": 1.0,
                         "extractor": extractor
@@ -358,7 +358,7 @@ class DateMatcher(object):
                     {
                         "start": entities[i]["start"],
                         "end": entities[i]["end"],
-                        "entity": "date_time",
+                        "entity": "date",
                         "value": convert_date_to_timestamp(value[i]),
                         "confidence": 1.0,
                         "extractor": extractor
