@@ -1,3 +1,5 @@
+import os
+
 def get_dep_dict():
     d = {}
 
@@ -170,9 +172,12 @@ def get_dep_symptoms_dict():
 
     return d
 
-def get_list_of_symps(path="vi_nlp_core/utils/symptoms.txt"):
+ROOT_DIR = os.path.abspath(os.path.join(os.path.dirname(__file__), ".."))
+SYMPTOMS_PATH = os.path.join(ROOT_DIR,"data/symptoms.txt")
+
+def get_list_of_symps():
     data = []
-    with open(path,'r',encoding='utf-8') as f:
+    with open(SYMPTOMS_PATH,'r',encoding='utf-8') as f:
         for line in f:
             data.append(line.replace('\n',''))
     return data 
\ No newline at end of file
